==> apo-ws-client-6.00.50.2-sources.jar: fr/univlorraine/apowsclient/creationSE/VersionEtapeDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour VersionEtapeDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="VersionEtapeDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codEtp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codVersionEtp" type="{VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt"/&gt;
 *         &lt;element name="libWeb" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="temHeb" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codDureeEtp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codSise" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="nbVolumeHoraire" type="{VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableDecimal" minOccurs="0"/&gt;
 *         &lt;element name="temTls" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codParcoursType" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="nbCreditsEuropeens" type="{VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableDecimal" minOccurs="0"/&gt;
 *         &lt;element name="codComposante" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="libCommentaire" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codConvention" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="nbPACES" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="listRegimes" type="{VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauRegimeDTO"/&gt;
 *         &lt;element name="listCIP" type="{VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauCipDTO"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "VersionEtapeDTO", namespace = "VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codEtp",
    "codVersionEtp",
    "libWeb",
    "temHeb",
    "codDureeEtp",
    "codSise",
    "nbVolumeHoraire",
    "temTls",
    "codParcoursType",
    "nbCreditsEuropeens",
    "codComposante",
    "libCommentaire",
    "codConvention",
    "nbPACES",
    "listRegimes",
    "listCIP"
})
public class VersionEtapeDTO {

    @XmlElement(required = true, nillable = true)
    protected String codEtp;
    @XmlElement(required = true, nillable = true)
    protected String codVersionEtp;
    @XmlElement(nillable = true)
    protected String libWeb;
    @XmlElement(nillable = true)
    protected String temHeb;
    @XmlElement(required = true, nillable = true)
    protected String codDureeEtp;
    @XmlElement(nillable = true)
    protected String codSise;
    @XmlElement(nillable = true)
    protected String nbVolumeHoraire;
    @XmlElement(nillable = true)
    protected String temTls;
    @XmlElement(nillable = true)
    protected String codParcoursType;
    @XmlElement(nillable = true)
    protected String nbCreditsEuropeens;
    @XmlElement(required = true, nillable = true)
    protected String codComposante;
    @XmlElement(nillable = true)
    protected String libCommentaire;
    @XmlElement(nillable = true)
    protected String codConvention;
    @XmlElement(nillable = true)
    protected String nbPACES;
    @XmlElement(required = true, nillable = true)
    protected TableauRegimeDTO listRegimes;
    @XmlElement(required = true, nillable = true)
    protected TableauCipDTO listCIP;

    /**
     * Obtient la valeur de la propriété codEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtp() {
        return codEtp;
    }

    /**
     * Définit la valeur de la propriété codEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtp(String value) {
        this.codEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codVersionEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVersionEtp() {
        return codVersionEtp;
    }

    /**
     * Définit la valeur de la propriété codVersionEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVersionEtp(String value) {
        this.codVersionEtp = value;
    }

    /**
     * Obtient la valeur de la propriété libWeb.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibWeb() {
        return libWeb;
    }

    /**
     * Définit la valeur de la propriété libWeb.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibWeb(String value) {
        this.libWeb = value;
    }

    /**
     * Obtient la valeur de la propriété temHeb.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemHeb() {
        return temHeb;
    }

    /**
     * Définit la valeur de la propriété temHeb.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemHeb(String value) {
        this.temHeb = value;
    }

    /**
     * Obtient la valeur de la propriété codDureeEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodDureeEtp() {
        return codDureeEtp;
    }

    /**
     * Définit la valeur de la propriété codDureeEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodDureeEtp(String value) {
        this.codDureeEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codSise.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodSise() {
        return codSise;
    }

    /**
     * Définit la valeur de la propriété codSise.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodSise(String value) {
        this.codSise = value;
    }

    /**
     * Obtient la valeur de la propriété nbVolumeHoraire.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbVolumeHoraire() {
        return nbVolumeHoraire;
    }

    /**
     * Définit la valeur de la propriété nbVolumeHoraire.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbVolumeHoraire(String value) {
        this.nbVolumeHoraire = value;
    }

    /**
     * Obtient la valeur de la propriété temTls.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemTls() {
        return temTls;
    }

    /**
     * Définit la valeur de la propriété temTls.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemTls(String value) {
        this.temTls = value;
    }

    /**
     * Obtient la valeur de la propriété codParcoursType.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodParcoursType() {
        return codParcoursType;
    }

    /**
     * Définit la valeur de la propriété codParcoursType.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodParcoursType(String value) {
        this.codParcoursType = value;
    }

    /**
     * Obtient la valeur de la propriété nbCreditsEuropeens.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbCreditsEuropeens() {
        return nbCreditsEuropeens;
    }

    /**
     * Définit la valeur de la propriété nbCreditsEuropeens.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbCreditsEuropeens(String value) {
        this.nbCreditsEuropeens = value;
    }

    /**
     * Obtient la valeur de la propriété codComposante.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodComposante() {
        return codComposante;
    }

    /**
     * Définit la valeur de la propriété codComposante.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodComposante(String value) {
        this.codComposante = value;
    }

    /**
     * Obtient la valeur de la propriété libCommentaire.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibCommentaire() {
        return libCommentaire;
    }

    /**
     * Définit la valeur de la propriété libCommentaire.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibCommentaire(String value) {
        this.libCommentaire = value;
    }

    /**
     * Obtient la valeur de la propriété codConvention.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodConvention() {
        return codConvention;
    }

    /**
     * Définit la valeur de la propriété codConvention.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodConvention(String value) {
        this.codConvention = value;
    }

    /**
     * Obtient la valeur de la propriété nbPACES.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbPACES() {
        return nbPACES;
    }

    /**
     * Définit la valeur de la propriété nbPACES.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbPACES(String value) {
        this.nbPACES = value;
    }

    /**
     * Obtient la valeur de la propriété listRegimes.
     * 
     * @return
     *     possible object is
     *     {@link TableauRegimeDTO }
     *     
     */
    public TableauRegimeDTO getListRegimes() {
        return listRegimes;
    }

    /**
     * Définit la valeur de la propriété listRegimes.
     * 
     * @param value
     *     allowed object is
     *     {@link TableauRegimeDTO }
     *     
     */
    public void setListRegimes(TableauRegimeDTO value) {
        this.listRegimes = value;
    }

    /**
     * Obtient la valeur de la propriété listCIP.
     * 
     * @return
     *     possible object is
     *     {@link TableauCipDTO }
     *     
     */
    public TableauCipDTO getListCIP() {
        return listCIP;
    }

    /**
     * Définit la valeur de la propriété listCIP.
     * 
     * @param value
     *     allowed object is
     *     {@link TableauCipDTO }
     *     
     */
    public void setListCIP(TableauCipDTO value) {
        this.listCIP = value;
    }

}

==> apo-ws-client-6.00.50.4-sources.jar: fr/univlorraine/apowsclient/creationSE/VersionEtapeDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour VersionEtapeDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="VersionEtapeDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codEtp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codVersionEtp" type="{VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt"/&gt;
 *         &lt;element name="libWeb" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="temHeb" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codDureeEtp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codSise" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="nbVolumeHoraire" type="{VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableDecimal" minOccurs="0"/&gt;
 *         &lt;element name="temTls" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codParcoursType" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="nbCreditsEuropeens" type="{VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableDecimal" minOccurs="0"/&gt;
 *         &lt;element name="codComposante" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="libCommentaire" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codConvention" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="nbPACES" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="listRegimes" type="{VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauRegimeDTO"/&gt;
 *         &lt;element name="listCIP" type="{VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauCipDTO"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "VersionEtapeDTO", namespace = "VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codEtp",
    "codVersionEtp",
    "libWeb",
    "temHeb",
    "codDureeEtp",
    "codSise",
    "nbVolumeHoraire",
    "temTls",
    "codParcoursType",
    "nbCreditsEuropeens",
    "codComposante",
    "libCommentaire",
    "codConvention",
    "nbPACES",
    "listRegimes",
    "listCIP"
})
public class VersionEtapeDTO {

    @XmlElement(required = true, nillable = true)
    protected String codEtp;
    @XmlElement(required = true, nillable = true)
    protected String codVersionEtp;
    @XmlElementRef(name = "libWeb", type = JAXBElement.class, required = false)
    protected JAXBElement<String> libWeb;
    @XmlElementRef(name = "temHeb", type = JAXBElement.class, required = false)
    protected JAXBElement<String> temHeb;
    @XmlElement(required = true, nillable = true)
    protected String codDureeEtp;
    @XmlElementRef(name = "codSise", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codSise;
    @XmlElementRef(name = "nbVolumeHoraire", type = JAXBElement.class, required = false)
    protected JAXBElement<String> nbVolumeHoraire;
    @XmlElementRef(name = "temTls", type = JAXBElement.class, required = false)
    protected JAXBElement<String> temTls;
    @XmlElementRef(name = "codParcoursType", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codParcoursType;
    @XmlElementRef(name = "nbCreditsEuropeens", type = JAXBElement.class, required = false)
    protected JAXBElement<String> nbCreditsEuropeens;
    @XmlElement(required = true, nillable = true)
    protected String codComposante;
    @XmlElementRef(name = "libCommentaire", type = JAXBElement.class, required = false)
    protected JAXBElement<String> libCommentaire;
    @XmlElementRef(name = "codConvention", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codConvention;
    @XmlElementRef(name = "nbPACES", type = JAXBElement.class, required = false)
    protected JAXBElement<String> nbPACES;
    @XmlElement(required = true, nillable = true)
    protected TableauRegimeDTO listRegimes;
    @XmlElement(required = true, nillable = true)
    protected TableauCipDTO listCIP;

    /**
     * Obtient la valeur de la propriété codEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtp() {
        return codEtp;
    }

    /**
     * Définit la valeur de la propriété codEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtp(String value) {
        this.codEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codVersionEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVersionEtp() {
        return codVersionEtp;
    }

    /**
     * Définit la valeur de la propriété codVersionEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVersionEtp(String value) {
        this.codVersionEtp = value;
    }

    /**
     * Obtient la valeur de la propriété libWeb.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getLibWeb() {
        return libWeb;
    }

    /**
     * Définit la valeur de la propriété libWeb.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setLibWeb(JAXBElement<String> value) {
        this.libWeb = value;
    }

    /**
     * Obtient la valeur de la propriété temHeb.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getTemHeb() {
        return temHeb;
    }

    /**
     * Définit la valeur de la propriété temHeb.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setTemHeb(JAXBElement<String> value) {
        this.temHeb = value;
    }

    /**
     * Obtient la valeur de la propriété codDureeEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodDureeEtp() {
        return codDureeEtp;
    }

    /**
     * Définit la valeur de la propriété codDureeEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodDureeEtp(String value) {
        this.codDureeEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codSise.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodSise() {
        return codSise;
    }

    /**
     * Définit la valeur de la propriété codSise.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodSise(JAXBElement<String> value) {
        this.codSise = value;
    }

    /**
     * Obtient la valeur de la propriété nbVolumeHoraire.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getNbVolumeHoraire() {
        return nbVolumeHoraire;
    }

    /**
     * Définit la valeur de la propriété nbVolumeHoraire.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setNbVolumeHoraire(JAXBElement<String> value) {
        this.nbVolumeHoraire = value;
    }

    /**
     * Obtient la valeur de la propriété temTls.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getTemTls() {
        return temTls;
    }

    /**
     * Définit la valeur de la propriété temTls.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setTemTls(JAXBElement<String> value) {
        this.temTls = value;
    }

    /**
     * Obtient la valeur de la propriété codParcoursType.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodParcoursType() {
        return codParcoursType;
    }

    /**
     * Définit la valeur de la propriété codParcoursType.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodParcoursType(JAXBElement<String> value) {
        this.codParcoursType = value;
    }

    /**
     * Obtient la valeur de la propriété nbCreditsEuropeens.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getNbCreditsEuropeens() {
        return nbCreditsEuropeens;
    }

    /**
     * Définit la valeur de la propriété nbCreditsEuropeens.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setNbCreditsEuropeens(JAXBElement<String> value) {
        this.nbCreditsEuropeens = value;
    }

    /**
     * Obtient la valeur de la propriété codComposante.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodComposante() {
        return codComposante;
    }

    /**
     * Définit la valeur de la propriété codComposante.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodComposante(String value) {
        this.codComposante = value;
    }

    /**
     * Obtient la valeur de la propriété libCommentaire.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getLibCommentaire() {
        return libCommentaire;
    }

    /**
     * Définit la valeur de la propriété libCommentaire.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setLibCommentaire(JAXBElement<String> value) {
        this.libCommentaire = value;
    }

    /**
     * Obtient la valeur de la propriété codConvention.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodConvention() {
        return codConvention;
    }

    /**
     * Définit la valeur de la propriété codConvention.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodConvention(JAXBElement<String> value) {
        this.codConvention = value;
    }

    /**
     * Obtient la valeur de la propriété nbPACES.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getNbPACES() {
        return nbPACES;
    }

    /**
     * Définit la valeur de la propriété nbPACES.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setNbPACES(JAXBElement<String> value) {
        this.nbPACES = value;
    }

    /**
     * Obtient la valeur de la propriété listRegimes.
     * 
     * @return
     *     possible object is
     *     {@link TableauRegimeDTO }
     *     
     */
    public TableauRegimeDTO getListRegimes() {
        return listRegimes;
    }

    /**
     * Définit la valeur de la propriété listRegimes.
     * 
     * @param value
     *     allowed object is
     *     {@link TableauRegimeDTO }
     *     
     */
    public void setListRegimes(TableauRegimeDTO value) {
        this.listRegimes = value;
    }

    /**
     * Obtient la valeur de la propriété listCIP.
     * 
     * @return
     *     possible object is
     *     {@link TableauCipDTO }
     *     
     */
    public TableauCipDTO getListCIP() {
        return listCIP;
    }

    /**
     * Définit la valeur de la propriété listCIP.
     * 
     * @param value
     *     allowed object is
     *     {@link TableauCipDTO }
     *     
     */
    public void setListCIP(TableauCipDTO value) {
        this.listCIP = value;
    }

}
